@@ -1,3 +1,19 @@
+# Breath of the Wild Actor Tool, edits actor files fin LoZ:BotW
+# Copyright (C) 2020 GingerAvalanche (chodness@gmail.com)
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published
+# by the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 import wx
 import zlib
 from pathlib import Path
@@ -89,9 +105,9 @@ class UiMainWindow(wx.Frame):
         settingsoption = settingsmenu.Append(wx.ID_ANY, "Settings", "Open the settings")
         menu.Append(settingsmenu, "&Settings")
 
-        debugmenu = wx.Menu()
-        textsoption = debugmenu.Append(wx.ID_ANY, "Print texts to console", "Test texts generator")
-        menu.Append(debugmenu, "&Debug")
+        # debugmenu = wx.Menu()
+        # textsoption = debugmenu.Append(wx.ID_ANY, "Print texts to console", "Test texts generator")
+        # menu.Append(debugmenu, "&Debug")
 
         self.SetMenuBar(menu)
 
@@ -100,7 +116,7 @@ class UiMainWindow(wx.Frame):
         self.Bind(wx.EVT_MENU, self.OnSave, saveoption)
         self.Bind(wx.EVT_MENU, self.OnQuit, quitmenuoption)
         self.Bind(wx.EVT_MENU, self.OnSettings, settingsoption)
-        self.Bind(wx.EVT_MENU, self.OnTexts, textsoption)
+        # self.Bind(wx.EVT_MENU, self.OnTexts, textsoption)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
 
         panelbox = wx.BoxSizer(wx.VERTICAL)
